package static

// PluginConf holds the plugin configuration.
type PluginConf map[string]any
